==> haskell-hslogger-1.2.12-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-3oTpf2jiEJmLwNsbsouR1F
key: hslogger-1.2.12-3oTpf2jiEJmLwNsbsouR1F
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: f933cc9acf85d3ee2aa707f7fc2244fd
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.6.3/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.6.3/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-3oTpf2jiEJmLwNsbsouR1F
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    network-2.8.0.0-2IPXD2Y68aq74YznYSHES6
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 process-1.6.3.0
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.2.12-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-F0MffX4tOREI9yTBXZilsJ
key: hslogger-1.2.12-F0MffX4tOREI9yTBXZilsJ
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: 95fb8694d6d7a76f4015accce677f0f0
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.6.4/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.6.4/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-F0MffX4tOREI9yTBXZilsJ
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    network-2.8.0.0-79Coriq35AYDs1MobOTL51
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 process-1.6.5.0
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
